@@ -18,7 +18,7 @@ ssl._create_default_https_context = ssl._create_unverified_context
 from termcolor import cprint
 from inspect import currentframe
 
-__version__ = '0.1.34'
+__version__ = '0.1.37'
 
 __info__ = {
     '2022/01/04: 0.1.18 加入 __info__。',
@@ -33,9 +33,12 @@ __info__ = {
     '2022/06/24: 0.1.28 加入 tLineNotify',
     '2022/06/26: 0.1.29 加入 my_addressable_IP()',
     '2022/06/29: 0.1.30 加入需要的module',
-    '2022/07/02: 0.1.32 加入 DefaultOrderedDict'
-    '2022/07/13: 0.1.33 加入 binance_copy_bot'
-    '2022/07/14: 0.1.34 加入 price_ticks_offset_dec() 要用 Decimal 避免float error'
+    '2022/07/02: 0.1.32 加入 DefaultOrderedDict',
+    '2022/07/13: 0.1.33 加入 binance_copy_bot',
+    '2022/07/14: 0.1.34 加入 price_ticks_offset_dec() 要用 Decimal 避免float error',
+    '2022/07/15: 0.1.35 binance_copy_bot() 改用 API方式',
+    '2022/07/16: 0.1.36 加入 read_warrant_bible()',
+    '2022/07/17: 0.1.37 加入 tredis'
 }
 
 _MYPYLIB_ROOT = os.path.abspath(os.path.dirname(__file__))
